.. _ecad_functions_api:

ECA&D indices
=============

icclim 5.2 comes with convenience functions to call each individual index from `icclim` namespace.
These functions are autogenerated and are stored in `_generated_api.py`.
Additionally, user custom indices can be called with the `icclim.custom_index`.

For example to use this new API with the index `su` you can do:

.. code-block:: python

    import glob
    import icclim
    summer_days = icclim.su(
        in_files=glob.glob("netcdf_files/tasmax*.nc"),
        out_file="summer_days.nc",
    )

Generated API
-------------

.. automodule:: icclim._generated_api
    :members:

    .. rubric:: Functions

    .. autosummary::

      cd
      cdd
      cfd
      csdi
      csu
      custom_index
      cw
      cwd
      dtr
      etr
      fd
      gd4
      hd17
      id
      prcptot
      r10mm
      r20mm
      r75p
      r75ptot
      r95p
      r95ptot
      r99p
      r99ptot
      rr1
      rx1day
      rx5day
      sd
      sd1
      sd50cm
      sd5cm
      sdii
      su
      tg
      tg10p
      tg90p
      tn
      tn10p
      tn90p
      tnn
      tnx
      tr
      tx
      tx10p
      tx90p
      txn
      txx
      vdtr
      wd
      wsdi
      ww
